Class: Decidim::Blogs::PostSerializer
- Inherits:
-
Exporters::Serializer
- Object
- Exporters::Serializer
- Decidim::Blogs::PostSerializer
- Includes:
- ApplicationHelper, ResourceHelper
- Defined in:
- lib/decidim/blogs/post_serializer.rb
Overview
This class serializes a Post so can be exported to CSV, JSON or other formats.
Instance Method Summary collapse
-
#initialize(post) ⇒ PostSerializer
constructor
Public: Initializes the serializer with a post.
-
#serialize ⇒ Object
Public: Exports a hash with the serialized data for this post.
Constructor Details
#initialize(post) ⇒ PostSerializer
Public: Initializes the serializer with a post.
12 13 14 |
# File 'lib/decidim/blogs/post_serializer.rb', line 12 def initialize(post) @post = post end |
Instance Method Details
#serialize ⇒ Object
Public: Exports a hash with the serialized data for this post.
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/decidim/blogs/post_serializer.rb', line 17 def serialize { id: post.id, author: { ** }, title: post.title, body: post.body, created_at: post.created_at, updated_at: post.updated_at, published_at: post.published_at, likes_count: post.likes_count, comments_count: post.comments_count, follows_count: post.follows_count, participatory_space: { id: post.participatory_space.id, url: Decidim::ResourceLocatorPresenter.new(post.participatory_space).url }, component: { id: component.id }, url: } end |